#
# spec file for package fcitx5-unikey
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%global sname fcitx5-unikey
%if "%{flavor}" == ""
%global pname %sname
%else
%global pname %{sname}-%{flavor}
%endif

Name:           %{pname}
Version:        5.1.6
Release:        1.2
Summary:        Unikey engine support for Fcitx5
License:        GPL-2.0-or-later AND LGPL-2.0-or-later
Group:          System/Localization
URL:            https://github.com/fcitx/fcitx5-unikey
Source:         https://download.fcitx-im.org/fcitx5/%{sname}/%{sname}-%{version}.tar.zst
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  fcitx5-devel
BuildRequires:  fcitx5-qt-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  zstd
%if "%{flavor}" == ""
BuildRequires:  libqt5-qtbase-devel
Requires:       fcitx5
Provides:       fcitx-unikey = %{version}
Obsoletes:      fcitx-unikey <= 0.2.7
Conflicts:      %{sname}-qt6
%endif
%if "%{flavor}" == "qt6"
BuildRequires:  qt6-base-devel
Conflicts:      %{sname}
%endif
%if 0%{?suse_version} <= 1520
BuildRequires:  appstream-glib-devel
%endif

%description
Chewing Wrapper for Fcitx5.

%prep
%setup -q -n %{sname}-%{version}

%build
%if "%{flavor}" == ""
%cmake -DUSE_QT6=OFF
%endif
%if "%{flavor}" == "qt6"
%if 0%{?suse_version} == 1500
%cmake -DCMAKE_CXX_COMPILER=%{_bindir}/g++-13
%else
%cmake
%endif
%endif
%make_build

%install
%cmake_install
%find_lang %{sname}

%files -f %{sname}.lang
%license LICENSES
%doc README
%{_fcitx5_libdir}/libunikey.so
%if "%{flavor}" == ""
%{_fcitx5_qt5dir}/libfcitx5-unikey-keymap-editor.so
%{_fcitx5_qt5dir}/libfcitx5-unikey-macro-editor.so
%endif
%if "%{flavor}" == "qt6"
%{_libdir}/fcitx5/qt6/libfcitx5-unikey-keymap-editor.so
%{_libdir}/fcitx5/qt6/libfcitx5-unikey-macro-editor.so
%endif
%{_fcitx5_addondir}/unikey.conf
%{_fcitx5_imconfdir}/unikey.conf
%{_datadir}/icons/hicolor/*/apps/fcitx-unikey*
%{_datadir}/icons/hicolor/*/apps/org.fcitx.Fcitx5.fcitx-unikey*
%{_datadir}/metainfo/org.fcitx.Fcitx5.Addon.Unikey.metainfo.xml

%changelog
* Wed Jan 29 2025 Marguerite Su <i@marguerite.su>
- update to 5.1.6
  * use addon factory v2
* Sat Jan 11 2025 Marguerite Su <i@marguerite.su>
- fix leap 15.6 build
  * use g++-13 to workaround the <filesystem> include
* Sun Jan  5 2025 Marguerite Su <i@marguerite.su>
- update to 5.1.5
  * translation update
* Thu May 23 2024 Marguerite Su <i@marguerite.su>
- update to 5.1.4
  * use qt6 by default
* Mon Feb  5 2024 Marguerite Su <i@marguerite.su>
- update to 5.1.2
  * add qt6 support
* Tue Oct  3 2023 Marguerite Su <i@marguerite.su>
- update to 5.1.1
  * translation update
* Sun Aug 20 2023 Marguerite Su <i@marguerite.su>
- update to 5.1.0
  * update unikey data to make it encode with ascii
- drop backport-allow-uoh.diff
- drop backport-commit-on-switchingIM.diff
- drop backport-rebuild-surrounding-state.diff
* Mon May 22 2023 Marguerite Su <i@marguerite.su>
- Update to 5.0.13
  * add all size of icon for unikey
  * allow to modify commited words
* Sun Nov 20 2022 Tranter Madi <trmdi@yandex.com>
- Update to 5.0.12
  * remove backports
* Mon Nov 14 2022 Tranter Madi <trmdi@yandex.com>
- Remove: fix-enter.diff, fix-uou.diff
- Backport fix:
  * Add backport-commit-on-switchingIM.diff
  * Add backport-rebuild-surrounding-state.diff
  * Add backport-allow-uoh.diff
* Sat Nov  5 2022 Tranter Madi <trmdi@yandex.com>
- Backport fix for github issues #23 and #24, add fix-enter.diff and
  fix-uou.diff
* Tue Jul  5 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 5.0.11
- Rename unikey.so to libunikey.so
- Add new file libfcitx5-unikey-keymap-editor.so
* Wed Mar 16 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.9
  * translation update
* Thu Feb 10 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.8
* Wed Dec  8 2021 Tranter Madi <trmdi@yandex.com>
- update version 5.0.7
* Fri Nov 12 2021 Tranter Madi <trmdi@yandex.com>
- update version 5.0.6
* Wed May  5 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.4
  * add addon version
* Tue Mar 16 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.3
* Sun Dec  6 2020 Marguerite Su <i@marguerite.su>
- update version 5.0.2
* Tue Nov 10 2020 Marguerite Su <i@marguerite.su>
- update version 5.0.0
* Fri Sep  4 2020 Marguerite Su <i@marguerite.su>
- initial package
